/**
  *  \file client/dialogs/simplanettorps.cc
  *  \brief Simulator Planetary Torpedoes Editor
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/simplanettorps.h"
#include "game/sim.h"
#include "game/spec.h"
#include "gfx/gfxcontext.h"
#include "gfx/palette.h"
#include "ui/commands.h"
#include "ui/layout.h"
#include "ui/skin.h"
#include "ui/uiglobal.h"
#include "ui/widgets/button.h"
#include "ui/widgets/decimalsel.h"
#include "ui/widgets/focusiterator.h"
#include "ui/window.h"
#include "util/misc.h"
#include "util/nls.h"
#include "ui/widgets/quit.h"
#include "ui/widgets/listlikenumbersel.h"

/** Edit torpedoes in a simulator planet.
    \param planet The planet
    \retval true Dialog was confirmed, planet possibly changed
    \retval false Dialog was cancelled, planet not changed */
bool
editSimulatorPlanetTorps(GSimPlanet& planet)
{
    UIListLikeNumberSelector* torp_edits[NUM_TORPS];
    ObjectHolder h;
    UIWindow& w = h.add(new UIWindow(_("Starbase Torpedoes"), UIWindow::BLUE_WINDOW, COLOR_GRAY));
    w.setLayout(UIVBoxLayout::instance5);

    UIGroup& group_torps   = h.add(new UIGroup(UIVBoxLayout::instance0));
    UIGroup& group_buttons = h.add(new UIGroup(UIHBoxLayout::instance5));
    for (int i = 1; i <= NUM_TORPS; ++i) {
        UIListLikeNumberSelector& tl = h.add(new UIListLikeNumberSelector(i, getTorp(i).getName(), 0, 10000, 10));
        tl.setValue(planet.getBaseTorps(i));
        torp_edits[i-1] = &tl;
        group_torps.add(tl);
    }
    group_torps.add(h.add(new UIFocusIterator(1, NUM_TORPS,
                                              UIFocusIterator::fi_Vert | UIFocusIterator::fi_Page | UIFocusIterator::fi_Home)));
    group_buttons.add(h.add(new UIButton(cm_Enter, _("OK"), SDLK_RETURN)).addStop());
    group_buttons.add(h.add(new UIButton(cm_Escape, _("Cancel"), SDLK_ESCAPE)).addStop());
    group_buttons.add(h.add(new UISpacer()));
    w.add(group_torps);
    w.add(group_buttons);
    w.add(h.add(new UIQuit(cm_Escape)));
    int focus_id = planet.getBaseTorpTech();
    torp_edits[focus_id-1]->setFocusedWidget();

    w.pack();
    ui_root->moveWidgetToEdge(w, 2, 2, 10);
    int rv = ui_root->runModal(w);
    if (rv == cm_Enter) {
        for (int i = 1; i <= NUM_TORPS; ++i) {
            planet.setBaseTorps(i, torp_edits[i-1]->getValue());
        }
        return true;
    } else {
        return false;
    }
}
