/**
  *  \file game/actions/baseparts.h
  *  \brief Starbase Action: Build Starship Parts
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_ACTIONS_BASEPARTS_H
#define PCC_V2_GAME_ACTIONS_BASEPARTS_H

#include "game/actions/basebuild.h"

class GStarbaseBuildPartsAction : public GStarbaseBuildAction {
    static const int INDEX_TABLE[];
    enum {
        FirstHull     = 0,
        FirstEngine   = FirstHull + NUM_HULLS_PER_PLAYER,
        FirstBeam     = FirstEngine + NUM_ENGINES,
        FirstLauncher = FirstBeam + NUM_BEAMS,
        TotalSlots    = FirstLauncher + NUM_TORPS
    };
    typedef int Item[TotalSlots];

    Item minimum;
    Item differences;
    bool have_undo_information;

    int  num_tech_updates_needed;
    bool need_reg_update;

    SignalConnection conn_update;

    static void copyFromPlanet(Item& item, const GPlanet& planet);

    void updateFromPlanet();
    void handleTechUpdate(GStarbaseBuildExecuter& a, TTechLevel kind, int level);

 public:
    GStarbaseBuildPartsAction(GPlanet& planet);
    ~GStarbaseBuildPartsAction();

    void addUndoInformation(const GPlanet& old_planet);
    int getMinimumParts(TTechLevel kind, int slot);
    int getExistingParts(TTechLevel kind, int slot);
    int getTotalParts(TTechLevel kind, int slot);
    int addParts(TTechLevel kind, int slot, int amount, bool partial);
    void perform(GStarbaseBuildExecuter& a);

    int getNumTechUpdates() const;
    bool isRegisteredUpdateNeeded() const;

    GError getError();
};

inline int
GStarbaseBuildPartsAction::getNumTechUpdates() const
{
    return num_tech_updates_needed;
}

inline bool
GStarbaseBuildPartsAction::isRegisteredUpdateNeeded() const
{
    return need_reg_update;
}



#endif
