/**
  *  \file game/unitscore.h
  *  \brief Per-Unit Scores
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_UNITSCORE_H
#define PCC_V2_GAME_UNITSCORE_H

#include <vector>
#include "game/utildata.h"

typedef TUtil49UnitScoreHeader TUnitScoreHeader;

enum {
    ScoreId_ExpLevel  = 1,
    ScoreId_ExpPoints = 2
};

/** Unit Score Definitions. Defines all Unit Scores for a particular
    type of units. It maps score types to indexes, and allows users to
    query these indexes. */
class GUnitScoreDefinitions {
    typedef std::vector<TUnitScoreHeader> defvec_t;
    defvec_t definitions;
 public:
    typedef defvec_t::size_type index_t;
    static const index_t nil = index_t(-1);

    GUnitScoreDefinitions();
    ~GUnitScoreDefinitions();

    index_t addScoreDefinition(const TUnitScoreHeader& header);
    const TUnitScoreHeader& getScoreDefinition(index_t index) const;
    index_t lookupScore(int16 score_type) const;
    index_t getNumScores() const;

    void clear();
};

/** Unit Score Values. Contains values for one unit. It is indexed by
    GUnitScoreDefinitions::index_t, obtained by the unit's class'
    GUnitScoreDefinitions object.  */
class GUnitScores {
    struct Item {
        int16 turn;          /* 0 means does not exist */
        int16 value;
    };
    std::vector<Item> items;
 public:
    GUnitScores();
    ~GUnitScores();

    void setScore(GUnitScoreDefinitions::index_t index, int16 value, int16 turn);
    void mergeScore(GUnitScoreDefinitions::index_t index, int16 value, int16 turn);

    int16 getTurn(GUnitScoreDefinitions::index_t index) const;
    int16 getScore(GUnitScoreDefinitions::index_t index) const;
};

void initUnitScores();
void doneUnitScores();

extern GUnitScoreDefinitions ship_score_definitions, planet_score_definitions;

#endif
